Skip to contents

List collections that are available from the Sentinel Hub.

Usage

dse_sh_collections(...)

Arguments

...

Ignored

Value

Returns a data.frame with information about the collections available from the Sentinel Hub

Examples

if (interactive()) {
  dse_sh_collections()
}