Skip to contents

Custom Eval Scripts, that can be used in Sentinel Hub requests, for processing data. This functions lists scripts available from https://github.com/sentinel-hub/custom-scripts. They can be retrieved with dse_sh_get_custom_script().

Usage

dse_sh_custom_scripts(...)

Arguments

...

Ignored

Value

Returns a data.frame with custom scripts, containing a column with a title and one with a relative URL.

Details

Make sure that you have sufficient monthly quota left to process images. You can check with dse_usage().

Examples

if (interactive()) {
  dse_sh_custom_scripts()
}