Create a OData Request for a Data Space Ecosystem Bursts Data
Source:R/odata_bursts.R
dse_odata_bursts.RdObtain metadata for burst data associated with specific products.
Details
For more details about bursts check the burst API documentation.
You can apply some tidyverse functions (see tidy_verbs) to odata_request
object returned by dse_odata_bursts_request(). These apply lazy evaluation.
Meaning that they are just added to the object and are only evaluated after
calling either dplyr::compute() or dplyr::collect() (see examples).
Examples
if (interactive()) {
dse_odata_bursts(ParentProductId == "879d445c-2c67-5b30-8589-b1f478904269")
burst_req <-
dse_odata_bursts_request(ParentProductId == "879d445c-2c67-5b30-8589-b1f478904269")
## Note that these are large files and may take a while to download:
dse_odata_download(
burst_req,
tempdir()
)
}