R/sentinelhub.R
dse_sh_collections.Rd
List collections that are available from the Sentinel Hub.
dse_sh_collections(...)
Ignored
Returns a data.frame with information about the collections available from the Sentinel Hub
data.frame
if (interactive()) { dse_sh_collections() }