Return queryable fields for a specific collection on Sentinel Hub.
This is useful information when composing a query with
dse_sh_prepare_input(). Use dse_sh_collections() to list
available collections.
Usage
dse_sh_queryables(collection, ..., token = dse_access_token())Arguments
- collection
Collection id for which to obtain queryable fields.
- ...
Ignored.
- token
For authentication, many of the Dataspace Ecosystem uses an access token. Either provide your access token, or obtain one automatically with
dse_access_token()(default). Without a valid token you will likely get an "access denied" error.
Examples
if (interactive() && dse_has_client_info()) {
dse_sh_queryables("sentinel-2-l1c")
}