Use the STAC API to get a summary of all collections available from the interface.
Examples
if (interactive()) {
dse_stac_collections()
dse_stac_collections("sentinel-2-l2a")
}
Use the STAC API to get a summary of all collections available from the interface.
if (interactive()) {
dse_stac_collections()
dse_stac_collections("sentinel-2-l2a")
}